package net.knarcraft.dynmapcitizens.formatting;

import net.knarcraft.knarlib.formatting.TranslatableMessage;

/**
 * An enum describing all of DynmapCitizens' translatable messages
 */
public enum QuestsTranslatableMessage implements TranslatableMessage {

    /**
     * The format for a quest's planner description
     *
     * <p>Placeholders: {questCoolDown}, {questFrom}, {questUntil}, {questRepeat}</p>
     */
    QUESTS_PLANNER_DESCRIPTION,

    /**
     * The format for a quest's cool-down
     *
     * <p>Placeholders: {coolDown}</p>
     */
    QUESTS_PLANNER_COOL_DOWN,

    /**
     * The text to display if a quest cannot be repeated
     */
    QUESTS_PLANNER_UNREPEATABLE,

    /**
     * The format for a quest's first availability date
     *
     * <p>Placeholders: {startDate}</p>
     */
    QUESTS_PLANNER_FROM,

    /**
     * The format for a quest's last availability date
     *
     * <p>Placeholders: {endDate}</p>
     */
    QUESTS_PLANNER_UNTIL,

    /**
     * The format for a quest's repeat delay
     *
     * <p>Placeholders: {repeatDelay}</p>
     */
    QUESTS_PLANNER_REPEAT,

    /**
     * The format for displaying a planner timestamp
     */
    QUESTS_PLANNER_TIMESTAMP_FORMAT,

    /**
     * The format for a quest's requirements
     *
     * <p>Placeholders: {requirementQuestPoints}, {requirementExp}, {requirementBlockedByQuests},
     * {requirementRequiredQuests}, {requirementRequiredItems}, {requirementMCMMOSkills}, {requirementPermissions},
     * {requirementCustom}</p>
     */
    QUESTS_REQUIREMENTS_FORMAT,

    /**
     * The format for a quest's quest point requirement
     *
     * <p>Placeholders: {questPoints}</p>
     */
    QUESTS_REQUIREMENTS_QUEST_POINTS,

    /**
     * The format for a quest's exp requirement
     *
     * <p>Placeholders: {exp}</p>
     */
    QUESTS_REQUIREMENTS_EXP,

    /**
     * The format for a quest's blocking quests
     *
     * <p>Placeholders: {blockingQuests}</p>
     */
    QUESTS_REQUIREMENTS_BLOCKED_BY_QUEST_FORMAT,

    /**
     * The format for one of a quest's blocking quests
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_REQUIREMENTS_BLOCKED_BY_QUEST_ITEM,

    /**
     * The format for a quest's required quests
     *
     * <p>Placeholders: {requiredQuests}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_QUEST_FORMAT,

    /**
     * The format for one of a quest's required quests
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_QUEST_ITEM,

    /**
     * The format for a quest's required items
     *
     * <p>Placeholders: {requiredItems}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_ITEM_FORMAT,

    /**
     * The format for one of a quest's required items
     *
     * <p>Placeholders: {itemName}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_ITEM_ITEM,

    /**
     * The format for a quest's mcMMO skill requirement
     *
     * <p>Placeholders: {skill}, {level}</p>
     */
    QUESTS_REQUIREMENTS_MC_MMO_SKILL,

    /**
     * The format for a quest's required permissions
     *
     * <p>Placeholders: {permissions}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_PERMISSION_FORMAT,

    /**
     * The format for one of a quest's required permissions
     *
     * <p>Placeholders: {permission}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_PERMISSION_ITEM,

    /**
     * The format for a quest's reach area name
     *
     * <p>Placeholders: {name}</p>
     */
    QUESTS_REACH_AREA_NAME_FORMAT,

    /**
     * The format for a quest's reach area's description
     *
     * <p>Placeholders: {areaName}, {questName}</p>
     */
    QUESTS_REACH_AREA_DESCRIPTION_FORMAT,

    /**
     * The format for a quest's kill area name
     *
     * <p>Placeholders: {name}</p>
     */
    QUESTS_KILL_AREA_NAME_FORMAT,

    /**
     * The format for a quest's kill area description
     *
     * <p>Placeholders: {areaName}, {questName}, {mobName}, {mobAmount}</p>
     */
    QUESTS_KILL_AREA_DESCRIPTION_FORMAT,

    /**
     * The format for a quest's rewards
     *
     * <p>Placeholders: {money}, {experience}, {questPoints}, {permissions}, {items}, {commands}</p>
     */
    QUESTS_REWARDS_FORMAT,

    /**
     * The format for a quest's money reward
     *
     * <p>Placeholders: {amount}, {currency}</p>
     */
    QUESTS_REWARDS_MONEY,

    /**
     * The format for a quest's experience reward
     *
     * <p>Placeholders: {amount}</p>
     */
    QUESTS_REWARDS_EXPERIENCE,

    /**
     * The format for a quest's quest point reward
     *
     * <p>Placeholders: {amount}</p>
     */
    QUESTS_REWARDS_QUEST_POINTS,

    /**
     * The format for one of a quest's permission rewards
     *
     * <p>Placeholders: {permission}</p>
     */
    QUESTS_REWARDS_PERMISSION,

    /**
     * The format for one of a quest's item rewards
     *
     * <p>Placeholders: {item}</p>
     */
    QUESTS_REWARDS_ITEM,

    /**
     * The format for one of a quest's command rewards
     *
     * <p>Placeholders: {command}</p>
     */
    QUESTS_REWARDS_COMMAND,

    /**
     * The format for displaying a quest marker name
     *
     * <p>Placeholders: {name}</p>
     */
    QUESTS_MARKER_NAME_FORMAT,

    /**
     * The format for displaying offered quests on a quest NPC marker
     *
     * <p>Placeholders: {quests}</p>
     */
    QUESTS_OFFERED_FORMAT,

    /**
     * The format for displaying one of the quests on a quest NPC marker
     *
     * <p>Placeholders: {name}, {description}, {stages}, {rewards}, {requirements}, {planner}</p>
     */
    QUESTS_OFFERED_QUEST_FORMAT,

    /**
     * The format for displaying the different quests an NPC is involved in
     *
     * <p>Placeholders: {involvedQuests}</p>
     */
    QUESTS_INVOLVED_IN_FORMAT,

    /**
     * The format for displaying that the NPC is a kill target in a quest
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_INVOLVED_IN_KILL,

    /**
     * The format for displaying that the NPC is a delivery target in a quest
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_INVOLVED_IN_DELIVERY_TARGET,

    /**
     * The format for displaying that the NPC is a interaction target in a quest
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_INVOLVED_IN_INTERACT,
    ;

    @Override
    public TranslatableMessage[] getAllMessages() {
        return QuestsTranslatableMessage.values();
    }
}
